==> ver.B.b17.03.tar.gz: ver.B.b17.03/env/src/h/gb.h <==
/**********************************************************************
 
	Copyright (C) 2004 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/

#ifndef ___GB_H___
#define ___GB_H___

XL_SEXP *get_meta(XLISP_ENV * env,XL_SEXP * s);
void	init_gbs();
void	init_gb();
void	init_r64_function(XLISP_ENV*,XLISP_ENV*);
unsigned int get_file_modify(L_CHAR * filename,char * prefix);L_CHAR * get_access_path(URL * u,char *);
XL_SEXP * gb_MPTrigger(XLISP_ENV * env,XL_SEXP * s,
	XLISP_ENV * a,
	     XL_SYM_FIELD * sf);
void init_gb_MPTrigger(XLISP_ENV * env);
void send_cindex(L_CHAR * crd);

void	init_Set(XLISP_ENV *);
void	init_gb_Get(XLISP_ENV *);
void	init_gb_GetMeta(XLISP_ENV *);
void	init_gb_MPRouting(XLISP_ENV *);
void	init_gb_MPTrigger(XLISP_ENV *);
void	init_gb_MPPurge(XLISP_ENV *);
void	init_gb_MPcindex(XLISP_ENV *);
void	init_gb_resolve_mapping_path(XLISP_ENV *);
void 	init_gb_convert_coordinate(XLISP_ENV *);
void	init_fetch();
void	init_mp_work();
void	init_lump();
void	init_MPTrigger(XLISP_ENV *);
void	init_MPPurge(XLISP_ENV *);
void	init_MPStart(XLISP_ENV *);
void	init_gb_MPRouting(XLISP_ENV *);
void	init_MPstatus(XLISP_ENV *);
void	init_MPcindex(XLISP_ENV *);
void	init_mp_Exit(XLISP_ENV *);
void	init_acrp_function(XLISP_ENV*,XLISP_ENV*);
void init_std_function(XLISP_ENV * env0,XLISP_ENV * env1);
void xl_setup_file_nowait(int argc,char ** argv);

void	init_gv_flame_initial(XLISP_ENV *);

void init_gv_flame_open(XLISP_ENV * env);
void init_gv_flame_close(XLISP_ENV * env);
void init_gv_flame_set_overlay(XLISP_ENV * env);
void init_gv_flame_radar(XLISP_ENV * env);
void	init_gv_flame_status(XLISP_ENV *);
void	init_gv_flame_set_status(XLISP_ENV *);
void	init_gv_flame_point_status(XLISP_ENV *);
void	init_gv_flame_zoom(XLISP_ENV *);
void	init_gv_flame_move(XLISP_ENV *);
void	init_gv_flame_rotate(XLISP_ENV *);
void	init_gv_flame_redraw(XLISP_ENV *);
void	init_gv_flame_get_image(XLISP_ENV *);
void	init_gv_flame_click(XLISP_ENV *);
void	init_gv_flame_event(XLISP_ENV *);
void	init_gv_flame_purge_select(XLISP_ENV *);
void	init_gv_flame_dec_seq(XLISP_ENV *);
void init_gbview_function(XLISP_ENV * env0, XLISP_ENV * env1);
void init_gv_flame_loading_status(XLISP_ENV * env);
void init_gv_http_agent(XLISP_ENV * e0,XLISP_ENV * e1);
void init_gvImageSpider(XLISP_ENV * env0,XLISP_ENV * env1);
void init_gvGetWorldfile(XLISP_ENV * env0,XLISP_ENV * env1);


#endif

==> ver.B.b17.13.tar.gz: ver.B.b17.13/env/src/h/gb.h <==
/**********************************************************************
 
	Copyright (C) 2004 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/

#ifndef ___GB_H___
#define ___GB_H___

XL_SEXP *get_meta(XLISP_ENV * env,XL_SEXP * s);
void	init_gbs();
void	init_gb();
void	init_r64_function(XLISP_ENV*,XLISP_ENV*);
unsigned int get_file_modify(L_CHAR * filename,char * prefix);L_CHAR * get_access_path(URL * u,char *);
XL_SEXP * gb_MPTrigger(XLISP_ENV * env,XL_SEXP * s,
	XLISP_ENV * a,
	     XL_SYM_FIELD * sf);
void init_gb_MPTrigger(XLISP_ENV * env);
void send_cindex(L_CHAR * crd);

void	init_Set(XLISP_ENV *);
void	init_gb_Get(XLISP_ENV *);
void	init_gb_GetMeta(XLISP_ENV *);
void	init_gb_MPRouting(XLISP_ENV *);
void	init_gb_MPTrigger(XLISP_ENV *);
void	init_gb_MPPurge(XLISP_ENV *);
void	init_gb_MPcindex(XLISP_ENV *);
void	init_gb_resolve_mapping_path(XLISP_ENV *);
void 	init_gb_convert_coordinate(XLISP_ENV *);
void	init_fetch();
void	init_mp_work();
void	init_lump();
void	init_MPTrigger(XLISP_ENV *);
void	init_MPPurge(XLISP_ENV *);
void	init_MPStart(XLISP_ENV *);
void	init_gb_MPRouting(XLISP_ENV *);
void	init_MPstatus(XLISP_ENV *);
void	init_MPcindex(XLISP_ENV *);
void	init_mp_Exit(XLISP_ENV *);
void	init_acrp_function(XLISP_ENV*,XLISP_ENV*);
void init_std_function(XLISP_ENV * env0,XLISP_ENV * env1);
void xl_setup_file_nowait(int argc,char ** argv);

void	init_gv_frame_initial(XLISP_ENV *);

void init_gv_frame_open(XLISP_ENV * env);
void init_gv_frame_close(XLISP_ENV * env);
void init_gv_frame_set_overlay(XLISP_ENV * env);
void init_gv_frame_radar(XLISP_ENV * env);
void	init_gv_frame_status(XLISP_ENV *);
void	init_gv_frame_set_status(XLISP_ENV *);
void	init_gv_frame_point_status(XLISP_ENV *);
void	init_gv_frame_zoom(XLISP_ENV *);
void	init_gv_frame_move(XLISP_ENV *);
void	init_gv_frame_rotate(XLISP_ENV *);
void	init_gv_frame_redraw(XLISP_ENV *);
void	init_gv_frame_get_image(XLISP_ENV *);
void	init_gv_frame_click(XLISP_ENV *);
void	init_gv_frame_event(XLISP_ENV *);
void	init_gv_frame_purge_select(XLISP_ENV *);
void	init_gv_frame_dec_seq(XLISP_ENV *);
void init_gbview_function(XLISP_ENV * env0, XLISP_ENV * env1);
void init_gv_frame_loading_status(XLISP_ENV * env);
void init_gv_http_agent(XLISP_ENV * e0,XLISP_ENV * e1);
void init_gvImageSpider(XLISP_ENV * env0,XLISP_ENV * env1);
void init_gvGetWorldfile(XLISP_ENV * env0,XLISP_ENV * env1);


#endif
